Scan

Trait Scan 

pub trait Scan: Sized {
    type Err: Error;

    // Required method
    fn scan(buf: &str) -> (Result<Self, Self::Err>, usize);
}

Required Associated Types

Required Methods

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl Scan for char

Source

type Err = ParseCharError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for f32

Source

type Err = ParseFloatError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for f64

Source

type Err = ParseFloatError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for i8

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for i16

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for i32

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for i64

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for i128

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for isize

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for u8

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for u16

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for u32

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for u64

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for u128

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for usize

Source

type Err = ParseIntError

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl Scan for String

Source

type Err = Infallible

Source

fn scan(buf: &str) -> (Result<Self, Self::Err>, usize)

Source

impl<A, B> Scan for (A, B)
where A: Scan, B: Scan,

Source

impl<A, B, C> Scan for (A, B, C)
where A: Scan, B: Scan, C: Scan,

Source

impl<A, B, C, D> Scan for (A, B, C, D)
where A: Scan, B: Scan, C: Scan, D: Scan,

Source

impl<A, B, C, D, E> Scan for (A, B, C, D, E)
where A: Scan, B: Scan, C: Scan, D: Scan, E: Scan,

Source

impl<A, B, C, D, E, F> Scan for (A, B, C, D, E, F)
where A: Scan, B: Scan, C: Scan, D: Scan, E: Scan, F: Scan,

Source

impl<A, B, C, D, E, F, G> Scan for (A, B, C, D, E, F, G)
where A: Scan, B: Scan, C: Scan, D: Scan, E: Scan, F: Scan, G: Scan,

Source

impl<A, B, C, D, E, F, G, H> Scan for (A, B, C, D, E, F, G, H)
where A: Scan, B: Scan, C: Scan, D: Scan, E: Scan, F: Scan, G: Scan, H: Scan,

Source

impl<A, B, C, D, E, F, G, H, I> Scan for (A, B, C, D, E, F, G, H, I)
where A: Scan, B: Scan, C: Scan, D: Scan, E: Scan, F: Scan, G: Scan, H: Scan, I: Scan,

Source

impl<A, B, C, D, E, F, G, H, I, J> Scan for (A, B, C, D, E, F, G, H, I, J)
where A: Scan, B: Scan, C: Scan, D: Scan, E: Scan, F: Scan, G: Scan, H: Scan, I: Scan, J: Scan,

Source

impl<A, B, C, D, E, F, G, H, I, J, K> Scan for (A, B, C, D, E, F, G, H, I, J, K)
where A: Scan, B: Scan, C: Scan, D: Scan, E: Scan, F: Scan, G: Scan, H: Scan, I: Scan, J: Scan, K: Scan,

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> Scan for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: Scan, B: Scan, C: Scan, D: Scan, E: Scan, F: Scan, G: Scan, H: Scan, I: Scan, J: Scan, K: Scan, L: Scan,

Implementors